export const ColorLegend = ({
  colorScale,
  tickSpacing = 20,
  tickSize = 10,
  tickTextOffset = 20,
  onClick,
  selectedValue,
  onHover,
  hoveredValue,
  hoverOpacity,
  fadeOpacity
}) =>
  colorScale.domain().map((domainValue, i) => {
    const highlightSelection = () => {
      if (domainValue === selectedValue)
        return <circle fill={'darkred'} r={tickSize * 1.25} />;
    };
    const highlightSelectedFont = () => {
      if (domainValue === selectedValue)
        return {fontWeight: 'bold'};
    };
    return (
      <g
        className="tick"
        transform={`translate(0,${i * tickSpacing})`}
        onClick={() => {
          onClick(domainValue);
        }}
        onMouseEnter={() => {
          onHover(domainValue);
        }}
        onMouseOut={() => {
          onHover(null);
        }}
        opacity={
          domainValue === selectedValue || domainValue === hoveredValue
            ? hoverOpacity
            : fadeOpacity
        }
      >
        {highlightSelection()}
        <circle fill={colorScale(domainValue)} r={tickSize} />
        <text x={tickTextOffset} dy=".32em" style={highlightSelectedFont()}>
          {domainValue}
        </text>
      </g>
    );
  });
